@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from ibm_watson_machine_learning.utils.log_util import get_logger
+import logging
 from ibm_watson_machine_learning.utils import version
 
 #from ibm_watson_machine_learning.learning_system import LearningSystem
@@ -65,7 +65,7 @@ import sys
 class APIClient:
 
     def __init__(self, wml_credentials, project_id=None):
-        self._logger = get_logger(__name__)
+        self._logger = logging.getLogger(__name__)
         self.wml_credentials = copy.deepcopy(wml_credentials)
         self.CAMS = None
         self.WSD = None
@@ -295,12 +295,12 @@ class APIClient:
             import sys
             if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
                 if self.CLOUD_PLATFORM_SPACES:
-                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021."
-                          "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create new assets using this client."
+                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021. "
+                          "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create new assets using this client. "
                           "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
                 elif self.ICP_PLATFORM_SPACES:
                     print("DEPRECATED!! The Python 3.6 framework is deprecated and will be removed from a future release. "
-                    "We recommend you migrate your assets and use a Python 3.7 framework instead."
+                    "We recommend you migrate your assets and use a Python 3.7 framework instead. "
                     "For details, see https://www.ibm.com/support/knowledgecenter/SSQNUZ_current/wsj/analyze-data/pm_service_supported_frameworks.html")
 
             self.service_instance = ServiceInstanceNewPlan(self)
