@@ -27,7 +27,6 @@ _DEFAULT_LIST_LENGTH = 0
 class Connections(WMLResource):
     """
     Store and manage your Connections.
-
     """
     ConfigurationMetaNames = ConnectionMetaNames()
     """MetaNames for Connection creation."""
@@ -108,24 +107,23 @@ class Connections(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def get_details(self, connection_id):
         """
-            Get connection details for the given unique Connection id.
+        Get connection details for the given unique Connection id.
 
-            **Parameters**
+        **Parameters**
 
-            .. important::
-                #. **connection_id**: Unique id of Connection\n
-                   **type**: str\n
+        .. important::
+            #. **connection_id**: Unique id of Connection\n
+                **type**: str\n
 
-            **Output**
+        **Output**
 
-            .. important::
-                **returns**: Metadata of the stored Connection\n
-                **return type**: dict\n
+        .. important::
+            **returns**: Metadata of the stored Connection\n
+            **return type**: dict\n
 
-            **Example**
-
-             >>> connection_details = client.connections.get_details(connection_id)
+        **Example**
 
+         >>> connection_details = client.connections.get_details(connection_id)
         """
         self._client._check_if_either_is_set()
         Connections._validate_type(connection_id, u'connection_id', STR_TYPE, True)
@@ -152,61 +150,61 @@ class Connections(WMLResource):
                 Creates a connection. Input to PROPERTIES field examples
 
                 1. MySQL
-                      client.connections.ConfigurationMetaNames.PROPERTIES: {
-                        "database": "database",
-                        "password": "password",
-                        "port": "3306",
-                        "host": "host url",
-                        "ssl": "false",
-                        "username": "username"
-                      }
+                      >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
+                      >>>   "database": "database",
+                      >>>   "password": "password",
+                      >>>   "port": "3306",
+                      >>>   "host": "host url",
+                      >>>   "ssl": "false",
+                      >>>   "username": "username"
+                      >>> }
 
                 2. Google Big query
 
                    a. Method1: Use service account json. The service account json generated can be provided as
                                input as-is. Provide actual values in json. Example is only indicative to show
-                               the fields. Refer to Google big query documents how to generate the service account json
+                               the fields. Refer to Google big query documents how to generate the service account json\n
 
-                      client.connections.ConfigurationMetaNames.PROPERTIES: {
-                          "type": "service_account",
-                          "project_id": "project_id",
-                          "private_key_id": "private_key_id",
-                          "private_key": "private key contents"
-                          "client_email": "client_email",
-                          "client_id": "client_id",
-                          "auth_uri": "https://accounts.google.com/o/oauth2/auth",
-                          "token_uri": "https://oauth2.googleapis.com/token",
-                          "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
-                          "client_x509_cert_url": "client_x509_cert_url"
-                      }
+                      >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
+                      >>>     "type": "service_account",
+                      >>>     "project_id": "project_id",
+                      >>>     "private_key_id": "private_key_id",
+                      >>>     "private_key": "private key contents",
+                      >>>     "client_email": "client_email",
+                      >>>     "client_id": "client_id",
+                      >>>     "auth_uri": "https://accounts.google.com/o/oauth2/auth",
+                      >>>     "token_uri": "https://oauth2.googleapis.com/token",
+                      >>>     "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
+                      >>>     "client_x509_cert_url": "client_x509_cert_url"
+                      >>> }
 
-                    b. Method2: Using OAuth Method. Refer to Google big query documents how to generate OAuth token
+                   b. Method2: Using OAuth Method. Refer to Google big query documents how to generate OAuth token\n
 
-                       client.connections.ConfigurationMetaNames.PROPERTIES: {
-                          "access_token": "access token generated for big query"
-                          "refresh_token": "refresh token"
-                          "project_id": "project_id",
-                          "client_secret": "This is your gmail account password",
-                          "client_id": "client_id"
-                      }
+                       >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
+                       >>>    "access_token": "access token generated for big query",
+                       >>>    "refresh_token": "refresh token",
+                       >>>    "project_id": "project_id",
+                       >>>    "client_secret": "This is your gmail account password",
+                       >>>   "client_id": "client_id"
+                       >>> }
 
                 3. MS SQL
-                     client.connections.ConfigurationMetaNames.PROPERTIES: {
-                          "database": "database",
-                          "password": "password",
-                          "port": "1433",
-                          "host": "host",
-                          "username": "username"
-                     }
+                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
+                     >>>      "database": "database",
+                     >>>      "password": "password",
+                     >>>      "port": "1433",
+                     >>>      "host": "host",
+                     >>>      "username": "username"
+                     >>> }
 
                 4. Tera data
-                     client.connections.ConfigurationMetaNames.PROPERTIES: {
-                          "database": "database",
-                          "password": "password",
-                          "port": "1433",
-                          "host": "host",
-                          "username": "username"
-                     }
+                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: {
+                     >>>      "database": "database",
+                     >>>      "password": "password",
+                     >>>      "port": "1433",
+                     >>>      "host": "host",
+                     >>>      "username": "username"
+                     >>> }
 
 
                 **Parameters**
@@ -224,17 +222,18 @@ class Connections(WMLResource):
                     **return type**: dict\n
 
                 **Example**
-                     >>> sqlserver_data_source_type_id = client.connections.get_datasource_type_uid_by_name('sqlserver')
-                     >>> connections_details = client.connections.create({
-                     >>> client.connections.ConfigurationMetaNames.NAME: "sqlserver connection",
-                     >>> client.connections.ConfigurationMetaNames.DESCRIPTION: "connection description",
-                     >>> client.connections.ConfigurationMetaNames.DATASOURCE_TYPE: sqlserver_data_source_type_id,
-                     >>> client.connections.ConfigurationMetaNames.PROPERTIES: { "database": "database",
-                     >>>                                                         "password": "password",
-                     >>>                                                         "port": "1433",
-                     >>>                                                         "host": "host",
-                     >>>                                                         "username": "username"}
-                     >>> })
+
+                 >>> sqlserver_data_source_type_id = client.connections.get_datasource_type_uid_by_name('sqlserver')
+                 >>> connections_details = client.connections.create({
+                 >>> client.connections.ConfigurationMetaNames.NAME: "sqlserver connection",
+                 >>> client.connections.ConfigurationMetaNames.DESCRIPTION: "connection description",
+                 >>> client.connections.ConfigurationMetaNames.DATASOURCE_TYPE: sqlserver_data_source_type_id,
+                 >>> client.connections.ConfigurationMetaNames.PROPERTIES: { "database": "database",
+                 >>>                                                         "password": "password",
+                 >>>                                                         "port": "1433",
+                 >>>                                                         "host": "host",
+                 >>>                                                         "username": "username"}
+                 >>> })
 
         """
         WMLResource._chk_and_block_create_update_for_python36(self)
@@ -362,19 +361,18 @@ class Connections(WMLResource):
 
     def list_datasource_types(self):
         """
-           List stored datasource types assets.
+        List stored datasource types assets.
 
 
-           **Output**
+        **Output**
 
-           .. important::
-                This method only prints the list of datasources type in a table format.\n
-                **return type**: None\n
+        .. important::
+            This method only prints the list of datasources type in a table format.\n
+            **return type**: None\n
 
-           **Example**
-
-            >>> client.connections.list_datasource_types()
+        **Example**
 
+         >>> client.connections.list_datasource_types()
         """
 
         if self._client.WSD:
