@@ -12,12 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import os
 from abc import ABC, abstractmethod
 from copy import copy
 from functools import wraps
 from typing import TYPE_CHECKING, Union, Dict
 from warnings import warn
-from time import sleep
+from contextlib import redirect_stdout
 
 from pandas import DataFrame
 
@@ -357,10 +358,17 @@ class BaseDeployment(ABC):
 
                 else:
                     if not self._target_workspace.wml_client.ICP:
+
+                        optimizer_2 = AutoAI(self._source_workspace).runs.get_optimizer(metadata=kwargs['metadata'])
+                        run_details = optimizer_2._workspace.wml_client.training.get_details(
+                            optimizer_2.get_params()['run_id']
+                        )
+
                         artifact_name, model_props = prepare_auto_ai_model_to_publish_notebook_normal_scenario(
                             pipeline_model=model,
                             result_connection=optimizer._result_client[0],
                             cos_client=optimizer._result_client[1],
+                            run_params=run_details,
                             space_id=self._target_workspace.space_id
                         )
 
@@ -577,23 +585,31 @@ class BaseDeployment(ABC):
     def _project_to_space_to_project(method):
         @wraps(method)
         def _method(self, *method_args, **method_kwargs):
-            self._target_workspace.wml_client.set.default_space(
-                self._target_workspace.space_id) if self._target_workspace.wml_client.ICP else None
+            with redirect_stdout(open(os.devnull, "w")):
+                self._target_workspace.wml_client.set.default_space(
+                    self._target_workspace.space_id) if self._target_workspace.wml_client.ICP else None
 
             try:
                 method_output = method(self, *method_args, **method_kwargs)
 
             except Exception as e:
                 if not self._target_workspace.WMLS:
-                    self._target_workspace.wml_client.set.default_project(
-                        self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
+                    with redirect_stdout(open(os.devnull, "w")):
+                        try:
+                            self._target_workspace.wml_client.set.default_project(
+                                self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
+                        except:
+                            pass
                 raise e
 
             else:
                 if not self._target_workspace.WMLS:
-                    self._target_workspace.wml_client.set.default_project(
-                        self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
-
+                    with redirect_stdout(open(os.devnull, "w")):
+                        try:
+                            self._target_workspace.wml_client.set.default_project(
+                                self._target_workspace.project_id) if self._target_workspace.wml_client.ICP else None
+                        except:
+                            pass
             return method_output
 
         return _method
