@@ -332,9 +332,9 @@ class Batch(BaseDeployment):
             return self.run_job(payload=payload_ref, output_data_reference=scoring_params['output_data_reference'],
                                 background_mode=background_mode)
         else:
-            payload_df = DataFrame.from_dict(scoring_params['input_data'])
-
-            return self.score(payload=payload_df, background_mode=background_mode)
+            raise NotImplementedError("'rerun_job' method supports only jobs with "
+                                      "payload passed as a list of DataConnections. If you want to rerun job "
+                                      "with payload passed directly, please use 'run_job' one more time.")
 
     @BaseDeployment._project_to_space_to_project
     def delete(self, deployment_id: str = None) -> None:
