@@ -12,9 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import logging
 import copy
-import sys
 from typing import List, Union
 
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
@@ -22,7 +20,7 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
     TShirtSize, ClassificationAlgorithms, RegressionAlgorithms, PredictionType, Metrics, Transformers,
     DataConnectionTypes, PipelineTypes, PositiveLabelClass)
 from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemoteParameter, MissingPositiveLabel
-from ibm_watson_machine_learning.utils.autoai.utils import is_ipython, check_dependencies_versions,\
+from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions,\
     validate_additional_params_for_optimizer
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
@@ -33,9 +31,6 @@ from ..base_experiment.base_experiment import BaseExperiment
 __all__ = [
     "AutoAI"
 ]
-# note: disable logging if we are in Jupyter Notebook (lale logs appear in wrong cell)
-if is_ipython:
-    logging.disable(sys.maxsize)
 
 
 class AutoAI(BaseExperiment):
@@ -56,7 +51,7 @@ class AutoAI(BaseExperiment):
     Example
     -------
     >>> from ibm_watson_machine_learning.experiment import AutoAI
-    >>> # Remote version of AutoAI
+    >>>
     >>> experiment = AutoAI(
     >>>        wml_credentials={
     >>>              "apikey": "...",
@@ -69,9 +64,6 @@ class AutoAI(BaseExperiment):
     >>>            },
     >>>         project_id="...",
     >>>         space_id="...")
-    >>>
-    >>> # Local version of AutoAI
-    >>> experiment = AutoAI()
     """
     # note: initialization of AutoAI enums as class properties
     ClassificationAlgorithms = ClassificationAlgorithms
@@ -158,6 +150,7 @@ class AutoAI(BaseExperiment):
                   encoding: str = 'utf-8',
                   positive_label: str = None,
                   data_join_only: bool = False,
+                  drop_duplicates: bool = True,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -226,6 +219,9 @@ class AutoAI(BaseExperiment):
         data_join_only: bool, optional
             If True only preprocessing will be executed.
 
+        drop_duplicates: bool, optional
+            If True duplicated rows in data will be removed before further processing. Default is True.
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -326,6 +322,7 @@ class AutoAI(BaseExperiment):
                 daub_include_only_estimators=daub_include_only_estimators,
                 cognito_transform_names=cognito_transform_names,
                 data_join_graph=data_join_graph,
+                drop_duplicates=drop_duplicates,
                 csv_separator=csv_separator,
                 excel_sheet=excel_sheet,
                 encoding=encoding,
