@@ -17,6 +17,7 @@ from typing import TYPE_CHECKING, List, Dict
 from pandas import DataFrame, MultiIndex
 import json
 from time import sleep
+import warnings
 
 from ibm_watson_machine_learning.utils.autoai.enums import (
     PredictionType, RegressionAlgorithms, ClassificationAlgorithms, RunStateTypes)
@@ -65,25 +66,6 @@ class WMLEngine(BaseEngine):
         Initialization of WML Pipeline Document (WML client Meta Parameter) with provided parameters and default ones.
         """
 
-        # note: if user does not specify algorithms to use, use all available
-        if self._auto_pipelines_parameters.get('daub_include_only_estimators') is None:
-            if self._auto_pipelines_parameters.get('prediction_type') == PredictionType.REGRESSION:
-                self._auto_pipelines_parameters['daub_include_only_estimators'] = [
-                    algorithm[1].value for algorithm in RegressionAlgorithms.__members__.items()]
-            else:
-                self._auto_pipelines_parameters['daub_include_only_estimators'] = [
-                    algorithm[1].value for algorithm in ClassificationAlgorithms.__members__.items()]
-        # --- end note
-        else:
-            # note: transform values from Enum
-            try:
-                self._auto_pipelines_parameters['daub_include_only_estimators'] = [
-                    algorithm.value for algorithm in self._auto_pipelines_parameters.get('daub_include_only_estimators')
-                ]
-            # note: if user pass strings instead of enums
-            except AttributeError:
-                pass
-
         self._wml_pipeline_metadata = {
             self._wml_client.pipelines.ConfigurationMetaNames.NAME:
                 self._auto_pipelines_parameters.get('name', 'Default name.'),
@@ -103,12 +85,11 @@ class WMLEngine(BaseEngine):
                             'output_logs': True,
                             'input_file_separator': self._auto_pipelines_parameters.get('csv_separator'),
                             'encoding': self._auto_pipelines_parameters.get('encoding'),
+                            'drop_duplicates': self._auto_pipelines_parameters.get('drop_duplicates'),
                             'optimization': {
                                 'learning_type': self._auto_pipelines_parameters.get('prediction_type'),
                                 'label': self._auto_pipelines_parameters.get('prediction_column'),
                                 'max_num_daub_ensembles': self._auto_pipelines_parameters.get('max_num_daub_ensembles'),
-                                "daub_include_only_estimators":
-                                    self._auto_pipelines_parameters.get('daub_include_only_estimators'),
                                 'cognito_transform_names':
                                     self._auto_pipelines_parameters.get('cognito_transform_names'),
                                 'scorer_for_ranking': self._auto_pipelines_parameters.get('scoring'),
@@ -176,6 +157,18 @@ class WMLEngine(BaseEngine):
                 'pipelines'][0]['nodes'][0]['parameters']['optimization'][
                 'daub_adaptive_subsampling_max_mem_usage'] = 25e9
 
+        if self._auto_pipelines_parameters.get('daub_include_only_estimators') is not None:
+            # note: transform values from Enum
+            try:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'daub_include_only_estimators'] = [
+                    algorithm.value for algorithm in self._auto_pipelines_parameters.get('daub_include_only_estimators')
+                ]
+            # note: if user pass strings instead of enums
+            except AttributeError:
+                pass
+
         # note: only pass positive label when scoring is binary
         if (self._auto_pipelines_parameters.get('positive_label')
                 and self._auto_pipelines_parameters.get('prediction_type') == PredictionType.BINARY):
@@ -365,11 +358,12 @@ class WMLEngine(BaseEngine):
         run_params = self._wml_client.training.run(meta_props=self._wml_training_metadata,
                                                    asynchronous=True)
 
+        self._current_run_id = run_params['metadata']['guid']
+
         if background_mode:
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
         else:
-            self._current_run_id = run_params['metadata']['guid']
             wml_pipeline_details = self.get_params()
             number_of_estimators = wml_pipeline_details.get('max_num_daub_ensembles', 2)
 
@@ -382,75 +376,88 @@ class WMLEngine(BaseEngine):
                 url = f"{url}?space_id={self._wml_client.default_space_id}"
 
             from lomond import WebSocket
-            websocket = WebSocket(url)
-
-            websocket.add_header(bytes("Authorization", "utf-8"),
-                                 bytes("Bearer " + self._wml_client.service_instance._get_token(), "utf-8"))
 
             gen = ProgressGenerator()
             end = False
 
             progress_bar = ProgressBar(desc="Total", total=gen.get_total(), position=0, ncols=100, bar_format='{l_bar}{bar}| [{elapsed}<{remaining}, ' '{rate_fmt}{postfix}]')
 
+            progress_bar.set_description(desc='Started waiting for resources')
+
             while not end:
-                progress_bar.set_description(desc='Started waiting for resources')
-                for event in websocket.connect():
-                    try:
-                        websocket.send_text('Ping')
-                    except:
-                        pass
-                    if event.name == 'text':
-                        status = json.loads(event.text)['entity']['status']
-                        if status.get('state') == RunStateTypes.FAILED:
-                            sleep(3)
+                websocket = WebSocket(url)
+                websocket.add_header(bytes("Authorization", "utf-8"),
+                                     bytes("Bearer " + self._wml_client.service_instance._get_token(), "utf-8"))
 
-                            message = status.get('message', {}).get('text', 'Training failed')
-                            progress_bar.set_description(desc=message)
-
-                            if 'Not Found' in str(message) or 'HeadObject' in str(message):
-                                raise AutoAIComputeError(self._current_run_id,
-                                                         reason=f"Fetching training data error. Please check if COS credentials, "
-                                                                f"bucket name and path are correct or file system path is correct.")
-
-                            elif 'Failed_Image' in str(message):
-                                raise AutoAIComputeError(
-                                    self._current_run_id,
-                                    reason=f"This version of WML V4 SDK with AutoAI component is no longer supported. "
-                                           f"Please update your package to the newest version. "
-                                           f"Error: {message}")
-
-                            else:
-                                raise AutoAIComputeError(self._current_run_id, reason=f"Error: {message}")
-                        elif 'message' in status and 'text' in status['message']:
-                            text = status['message']['text']
+                try:
+                    for event in websocket.connect():
+                        try:
+                            websocket.send_text('Ping')
+                        except:
+                            pass
+                        if event.name == 'text':
+                            status = json.loads(event.text)['entity']['status']
 
                             try:
                                 process = status['metrics'][0]['context']['intermediate_model']['process']
                             except:
                                 process = ''
 
-                            if self._current_run_id in text and 'completed' in text:
-                                end = True
-                                progress_bar.set_description(desc=text)
-                                progress_bar.last_update()
-                                progress_bar.close()
-                                break
-                            elif 'AutoAI model computed' not in text:
-                                prepared_text = text.split(': ')[-1].split("global:")[-1]
-                                max_len = 40
+                            if status.get('state') == RunStateTypes.FAILED:
+                                sleep(3)
+
+                                message = status.get('message', {}).get('text', 'Training failed')
+                                progress_bar.set_description(desc=message)
+
+                                if 'Not Found' in str(message) or 'HeadObject' in str(message):
+                                    raise AutoAIComputeError(self._current_run_id,
+                                                             reason=f"Fetching training data error. Please check if COS credentials, "
+                                                                    f"bucket name and path are correct or file system path is correct.")
+
+                                elif 'Failed_Image' in str(message):
+                                    raise AutoAIComputeError(
+                                        self._current_run_id,
+                                        reason=f"This version of WML V4 SDK with AutoAI component is no longer supported. "
+                                               f"Please update your package to the newest version. "
+                                               f"Error: {message}")
 
-                                if len(prepared_text) > max_len:
-                                    progress_bar.set_description(desc=prepared_text[:(max_len-3)] + '...')
                                 else:
-                                    progress_bar.set_description(desc=prepared_text + ' '*(max_len-len(prepared_text)))
+                                    raise AutoAIComputeError(self._current_run_id, reason=f"Error: {message}")
+                            elif 'message' in status and 'text' in status['message']:
+                                text = status['message']['text']
 
-                            progress_bar.increment_counter(gen.get_progress(process))
-                            progress_bar.update()
-                    elif event.name in ['closing', 'disconnected']:
-                        end = True
-                        break
+                                if self._current_run_id in text and 'completed' in text:
+                                    end = True
+                                    progress_bar.set_description(desc=text)
+                                    progress_bar.last_update()
+                                    progress_bar.close()
+                                    break
+                                elif 'AutoAI model computed' not in text:
+                                    prepared_text = text.split(': ')[-1].split("global:")[-1]
+                                    max_len = 40
+
+                                    if len(prepared_text) > max_len:
+                                        progress_bar.set_description(desc=prepared_text[:(max_len - 3)] + '...')
+                                    else:
+                                        progress_bar.set_description(
+                                            desc=prepared_text + ' ' * (max_len - len(prepared_text)))
+
+                                progress_bar.increment_counter(gen.get_progress(process))
+                                progress_bar.update()
+                            elif process:
+                                progress_bar.increment_counter(gen.get_progress(process))
+                                progress_bar.update()
+                        elif event.name in ['closing']:
+                            end = True
+                            websocket.close()
+                            break
+                        elif event.name in ['disconnected']:
+                            websocket.close()
+                            break
+                except:
+                    websocket.close()
+                    break
 
-            websocket.close()
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
 
     def get_run_status(self) -> str:
@@ -461,6 +468,10 @@ class WMLEngine(BaseEngine):
         -------
         Dictionary with run status details.
         """
+
+        if self._current_run_id is None:
+            raise FitNeeded(reason="Firstly schedule a fit job by using the fit() method.")
+
         return self._wml_client.training.get_status(training_uid=self._current_run_id).get('state')
 
     def get_run_details(self) -> dict:
@@ -472,7 +483,11 @@ class WMLEngine(BaseEngine):
         Dictionary with AutoPipelineOptimizer fit/run details.
         """
 
+        if self._current_run_id is None:
+            raise FitNeeded(reason="Firstly schedule a fit job by using the fit() method.")
+
         details = self._wml_client.training.get_details(training_uid=self._current_run_id)
+
         if details['entity']['status'].get('metrics', False):
             del details['entity']['status']['metrics']
             return details
@@ -697,30 +712,13 @@ class WMLEngine(BaseEngine):
         """
         try_import_autoai_libs()
 
+        # note: Show warning if OBM
+        if 'auto_ai.obm' in str(self._wml_stored_pipeline_details):
+            warnings.warn("OBM pipeline can be used only for inspection and deployment purposes.", Warning, stacklevel=2)
+        # end note
+
         run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
 
-        try:
-            # note: get experiment information to retrieve Hybrid SW specs and look which scikit was used
-            _, request_json = prepare_auto_ai_model_to_publish_normal_scenario(
-                pipeline_model=pipeline_name,
-                run_params=run_params,
-                run_id=self._current_run_id,
-                wml_client=self._wml_client,
-                space_id=''
-            )
-
-            hybrid_sw_spec = request_json['hybrid_pipeline_software_specs'][-1]['name']
-            # below includes scikit version check
-            _, _ = get_sw_spec_and_type_based_on_sklearn(client=self._wml_client, spec=hybrid_sw_spec)
-            # --- end note
-        
-        # do nothing when we cannot find request.json on user COS
-        except Exception as e:
-            if 'HeadObject' in str(e):
-                pass
-            else:
-                raise e
-
         try:
             pipelines: Dict[str, 'Pipeline'] = fetch_pipelines(
                 run_params=run_params,
@@ -728,7 +726,7 @@ class WMLEngine(BaseEngine):
                 pipeline_name=pipeline_name,
                 load_pipelines=True,
                 store=persist,
-                wml_client=self._wml_client if self._wml_client.ICP else None
+                wml_client=self._wml_client
             )
 
         except Exception as e:
