@@ -13,5 +13,6 @@
 # limitations under the License.
 
 from ibm_watson_machine_learning.helpers.connections.connections import (
-    DataConnection, S3Connection, S3Location, FSLocation, DSLocation, CP4DAssetLocation,
-    WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation)
+    DataConnection, S3Connection, S3Location, FSLocation, AssetLocation, CP4DAssetLocation,
+    WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation,
+    NFSConnection, NFSLocation)
