@@ -758,7 +758,7 @@ class NFSLocation(BaseLocation):
         asset_info_response = requests.get(href,
                                            params=params, headers=workspace.wml_client._get_headers(None), verify=False)
         if asset_info_response.status_code != 200:
-            raise Exception(u"Failure during getting asset details", asset_info_response.json())['details']['file_size']
+            raise Exception(u"Failure during getting asset details", asset_info_response.json())
         return asset_info_response.json()['details']['file_size']
 
 
