@@ -15,8 +15,8 @@
 import requests
 import json
 import base64
+import logging
 from datetime import datetime, timedelta
-from ibm_watson_machine_learning.utils.log_util import get_logger
 from ibm_watson_machine_learning.wml_client_error import NoWMLCredentialsProvided, ApiRequestFailure, WMLClientError
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
 
@@ -26,7 +26,7 @@ class ServiceInstance:
         Connect, get details and check usage of your Watson Machine Learning service instance.
     """
     def __init__(self, client):
-        self._logger = get_logger(__name__)
+        self._logger = logging.getLogger(__name__)
         self._client = client
         self._ICP = client.ICP
         self._wml_credentials = client.wml_credentials
@@ -61,11 +61,17 @@ class ServiceInstance:
 
     def get_api_key(self):
         """
-             Get api_key  of Watson Machine Learning service.
-             :returns: api_key
-             :rtype: str
-             A way you might use me is:
-             >>> instance_details = client.service_instance.get_api_key()
+            Get api_key  of Watson Machine Learning service.
+
+            **Output**
+
+            .. important::
+                **returns** api_key\n
+                **return type**: str\n
+
+            **Example**
+
+                >>> instance_details = client.service_instance.get_api_key()
         """
         return self._wml_credentials['api_key']
 
