@@ -15,8 +15,8 @@
 import requests
 import json
 import base64
+import logging
 from datetime import datetime, timedelta
-from ibm_watson_machine_learning.utils.log_util import get_logger
 from ibm_watson_machine_learning.wml_client_error import NoWMLCredentialsProvided, ApiRequestFailure, WMLClientError
 from ibm_watson_machine_learning.href_definitions import HrefDefinitions
 
@@ -27,7 +27,7 @@ class ServiceInstanceNewPlan:
     """
 
     def __init__(self, client):
-        self._logger = get_logger(__name__)
+        self._logger = logging.getLogger(__name__)
         self._client = client
         self._wml_credentials = client.wml_credentials
 
