@@ -27,7 +27,7 @@ _DEFAULT_LIST_LENGTH = 50
 
 class PlatformSpaces(WMLResource):
     """
-    Store and manage your spaces. This is applicable only for IBM Cloud Pak™ for Data
+    Store and manage your spaces
     """
     ConfigurationMetaNames = SpacesPlatformMetaNames()
     MemberMetaNames = SpacesPlatformMemberMetaNames()
@@ -119,13 +119,14 @@ class PlatformSpaces(WMLResource):
                  >>> spaces_details = client.spaces.store(meta_props=metadata)
         """
 
+        WMLResource._chk_and_block_create_update_for_python36(self)
         # quick support for COS credentials instead of local path
         # TODO add error handling and cleaning (remove the file)
         PlatformSpaces._validate_type(meta_props, u'meta_props', dict, True)
 
         if ('compute' in meta_props or 'storage' in meta_props) and self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("'STORAGE' and 'COMPUTE' meta props are not applicable on "
-                                 "Cloud Pak for Data. If using any of these, remove and retry")
+                                 "IBM Cloud Pak® for Data. If using any of these, remove and retry")
 
         if 'storage' not in meta_props and self._client.CLOUD_PLATFORM_SPACES:
             raise WMLClientError("'STORAGE' is mandatory for cloud")
@@ -205,7 +206,7 @@ class PlatformSpaces(WMLResource):
             return spaces_details
 
     @staticmethod
-    def get_id(spaces_details):
+    def get_id(space_details):
         """
             Get space_id from space details.
 
@@ -223,13 +224,46 @@ class PlatformSpaces(WMLResource):
 
             **Example**
 
-             >>> space_details = client.spaces.get_details(space_id)
-             >>> space_uid = client.spaces.get_id(space_details)
+             >>> space_details = client.spaces.store(meta_props)
+             >>> space_id = client.spaces.get_id(space_details)
         """
 
-        PlatformSpaces._validate_type(spaces_details, u'spaces_details', object, True)
+        PlatformSpaces._validate_type(space_details, u'space_details', object, True)
 
-        return WMLResource._get_required_element_from_dict(spaces_details, u'spaces_details',
+        return WMLResource._get_required_element_from_dict(space_details, u'space_details',
+                                                           [u'metadata', u'id'])
+
+
+    @staticmethod
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
+    def get_uid(space_details):
+        """
+                Get Unique Id of the space. This method is deprecated. Use 'get_id(space_details)' instead
+
+                **Parameters**
+
+                .. important::
+
+                   #. **asset_details**:  Metadata of the space\n
+                      **type**: dict\n
+                      **type**: dict\n
+
+                **Output**
+
+                .. important::
+
+                    **returns**: Unique Id of space\n
+                    **return type**: str\n
+
+                **Example**
+
+                 >>> space_details = client.spaces.store(meta_props)
+                 >>> space_uid = client.spaces.get_uid(space_details)
+
+        """
+        PlatformSpaces._validate_type(space_details, u'space_details', object, True)
+
+        return WMLResource._get_required_element_from_dict(space_details, u'space_details',
                                                            [u'metadata', u'id'])
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -404,9 +438,10 @@ class PlatformSpaces(WMLResource):
                  >>> space_details = client.spaces.update(space_id, changes=metadata)
         """
 
+        WMLResource._chk_and_block_create_update_for_python36(self)
         if ('compute' in changes or 'storage' in changes) and self._client.ICP_PLATFORM_SPACES:
             raise WMLClientError("'STORAGE' and 'COMPUTE' meta props are not applicable on"
-                                 "Cloud Pak for Data. If using any of these, remove and retry")
+                                 "IBM Cloud Pak® for Data. If using any of these, remove and retry")
 
         if 'storage' in changes:
             raise WMLClientError("STORAGE cannot be updated")
