@@ -337,6 +337,7 @@ class OBMPipelineGraphBuilder:
                                       "hour": hour, "minute": minute,
                                       "min": min, "mean": mean, "variance": variance, "distinct_count": distinct_count,
                                       "ItemsetMI": item,
+                                      "ItemsetCOR": item,
                                       "SymbolRecent": recent, "window_max": window_max,
                                       "window_max_trend": window_max_trend,
                                       "window_mean": window_mean, "window_mean_trend": window_mean_trend,
@@ -466,12 +467,12 @@ class OBMPipelineGraphBuilder:
                                 fmt=time_format)
                         else:
                             kwargs = {}
-                            if op == "ItemsetMI":
+                            if op in ["ItemsetMI", "ItemsetCOR"]:
                                 if pattern is not None:
                                     kwargs['value'] = pattern
                                 else:
                                     kwargs['value'] = ""
-                                    print("Pattern missing for ItemsetMI")  # TODO: Raise an exception
+                                    print("Pattern missing for ItemsetMI or ItemsetCOR")  # TODO: Raise an exception
                             if re.split('(\\d+)', op)[0][:-1] in parameterized_functions:
                                 if op.startswith("window"):
                                     kwargs['size'] = int(re.split('(\\d+)', op)[1])
