@@ -127,39 +127,38 @@ class Repository(WMLResource):
 
     def store_experiment(self, meta_props):
         """
-           Create an experiment.
+        Create an experiment.
 
-           **Parameters**
+        **Parameters**
 
-           .. important::
-                #. **meta_props**:  meta data of the experiment configuration. To see available meta names use:\n
-                                    >>> client.experiments.ConfigurationMetaNames.get()
+        .. important::
+            #. **meta_props**:  meta data of the experiment configuration. To see available meta names use:\n
+                >>> client.experiments.ConfigurationMetaNames.get()
+               **type**: dict\n
 
-                   **type**: dict\n
+        **Output**
 
-           **Output**
+        .. important::
 
-                .. important::
-                   **returns**: Metadata of the experiment created\n
-                   **return type**: dict\n
+            **returns**: Metadata of the experiment created\n
+            **return type**: dict\n
 
-           **Example**
+        **Example**
 
-            >>> metadata = {
-            >>>  client.experiments.ConfigurationMetaNames.NAME: 'my_experiment',
-            >>>  client.experiments.ConfigurationMetaNames.EVALUATION_METRICS: ['accuracy'],
-            >>>  client.experiments.ConfigurationMetaNames.TRAINING_REFERENCES: [
-            >>>      {
-            >>>        'pipeline': {'href': pipeline_href_1}
-            >>>
-            >>>      },
-            >>>      {
-            >>>        'pipeline': {'href':pipeline_href_2}
-            >>>      },
-            >>>   ]
-            >>> }
-            >>> experiment_details = client.repository.store_experiment(meta_props=metadata)
-            >>> experiment_href = client.repository.get_experiment_href(experiment_details)
+        >>> metadata = {
+        >>>  client.experiments.ConfigurationMetaNames.NAME: 'my_experiment',
+        >>>  client.experiments.ConfigurationMetaNames.EVALUATION_METRICS: ['accuracy'],
+        >>>  client.experiments.ConfigurationMetaNames.TRAINING_REFERENCES: [
+        >>>      {
+        >>>        'pipeline': {'href': pipeline_href_1}
+        >>>      },
+        >>>      {
+        >>>        'pipeline': {'href':pipeline_href_2}
+        >>>      },
+        >>>   ]
+        >>> }
+        >>> experiment_details = client.repository.store_experiment(meta_props=metadata)
+        >>> experiment_href = client.repository.get_experiment_href(experiment_details)
         """
 
         if self._client.WSD:
@@ -359,12 +358,12 @@ class Repository(WMLResource):
 
                     In more complicated cases you should create proper metadata, similar to this one:\n
 
-                    >>> sw_spec_id = client.software_specifications.get_id_by_name('scikit-learn_0.22-py3.6')
+                    >>> sw_spec_id = client.software_specifications.get_id_by_name('scikit-learn_0.23-py3.7')
                     >>> sw_spec_id
                     >>> metadata = {
                     >>>        client.repository.ModelMetaNames.NAME: 'customer satisfaction prediction model',
                     >>>        client.repository.ModelMetaNames.SOFTWARE_SPEC_UID: sw_spec_id,
-                    >>>        client.repository.ModelMetaNames.TYPE: 'scikit-learn_0.22'
+                    >>>        client.repository.ModelMetaNames.TYPE: 'scikit-learn_0.23'
                     >>>}
 
                     In case when you want to provide input data schema of the model, you can provide it as part of meta
@@ -438,6 +437,7 @@ class Repository(WMLResource):
                     **return type**: dict\n
 
             **Example**
+
              >>> client.repository.clone(artifact_id=artifact_id,space_id=space_uid,action="copy")
 
             .. note::
@@ -528,147 +528,175 @@ class Repository(WMLResource):
 
             **Example**
 
-             The most simple use is (using `score` function):
+                 The most simple use is (using `score` function):\n
 
-             >>> meta_props = {
-             >>>    client.repository.FunctionMetaNames.NAME: "function",
-             >>>    client.repository.FunctionMetaNames.DESCRIPTION: "This is ai function",
-             >>>    client.repository.FunctionMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
+                 >>> meta_props = {
+                 >>>    client.repository.FunctionMetaNames.NAME: "function",
+                 >>>    client.repository.FunctionMetaNames.DESCRIPTION: "This is ai function",
+                 >>>    client.repository.FunctionMetaNames.SOFTWARE_SPEC_UID: "53dc4cf1-252f-424b-b52d-5cdd9814987f"}
 
-             >>> def score(payload):
-             >>>      values = [[row[0]*row[1]] for row in payload['values']]
-             >>>      return {'fields': ['multiplication'], 'values': values}
-             >>> stored_function_details = client.repository.store_function(score, meta_props)
+                 >>> def score(payload):
+                 >>>      values = [[row[0]*row[1]] for row in payload['values']]
+                 >>>      return {'fields': ['multiplication'], 'values': values}
+                 >>> stored_function_details = client.repository.store_function(score, meta_props)
 
-             Other, more interesting example is using generator function.
-             In this situation it is possible to pass some variables:
+                 Other, more interesting example is using generator function.
+                 In this situation it is possible to pass some variables:
 
-                >>> wml_creds = {...}
-                >>> def gen_function(wml_credentials=wml_creds, x=2):
-                        def f(payload):
-                            values = [[row[0]*row[1]*x] for row in payload['values']]
-                            return {'fields': ['multiplication'], 'values': values}
-                        return f
-                >>> stored_function_details = client.repository.store_function(gen_function, meta_props)
+                    >>> wml_creds = {...}
+                    >>> def gen_function(wml_credentials=wml_creds, x=2):
+                    >>>        def f(payload):
+                    >>>            values = [[row[0]*row[1]*x] for row in payload['values']]
+                    >>>            return {'fields': ['multiplication'], 'values': values}
+                    >>>        return f
+                    >>> stored_function_details = client.repository.store_function(gen_function, meta_props)
             """
 
         return self._client._functions.store(function, meta_props)
 
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_model_revision(self, model_uid):
         """
         Create a new version for a model.
 
-        :param model_uid:  model ID
-        :type model_uid: {str_type}
+        **Parameters**
 
-        :returns: model version details
-        :rtype: dict
+        .. important::
 
-         Example:
+            #. **model_uid**:  Model ID.\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: Model version details.\n
+            **return type**: dict\n
+
+        **Example**
 
             >>> stored_model_revision_details = client.repository.create_model_revision( model_uid="MODELID")
-
-         """
+        """
 
         return self._client._models.create_revision(model_uid=model_uid)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_pipeline_revision(self, pipeline_uid):
         """
         Create a new version for a model.
 
-        :param pipeline_uid:  Unique ID of the Pipeline
-        :type pipeline_uid: {str_type}
+        **Parameters**
 
-        :returns: pipeline version details
-        :rtype: dict
+        .. important::
 
-         Example:
+            #. **pipeline_uid**:  Unique ID of the Pipeline.\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: Pipeline version details.\n
+            **return type**: dict\n
+
+        **Example**
 
             >>> stored_pipeline_revision_details = client.repository.create_pipeline_revision( pipeline_uid)
-
-         """
+        """
 
         return self._client.pipelines.create_revision(pipeline_uid=pipeline_uid)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_function_revision(self, function_uid):
         """
         Create a new version for a function.
 
-        :param function_uid:  Unique ID of the function.
-        :type function_uid: {str_type}
+        **Parameters**
 
-        :returns: function version details
-        :rtype: dict
+        .. important::
 
-         Example:
+            #. **function_uid**:  Unique ID of the function.\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: Function version details.\n
+            **return type**: dict\n
+
+        **Example**
 
             >>> stored_function_revision_details = client.repository.create_function_revision( function_uid)
-
-         """
+        """
 
         return self._client._functions.create_revision(function_uid=function_uid)
 
+    @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_experiment_revision(self, experiment_uid):
         """
         Create a new version for a experiment.
 
-        :param experiment_uid:  Unique ID of the experiment.
-        :type experiment_uid: {str_type}
+        **Parameters**
 
-        :returns: experiment version details
-        :rtype: dict
+        .. important::
 
-         Example:
+            #. **experiment_uid**:  Unique ID of the experiment.\n
+               **type**: str\n
+
+        **Output**
+
+        .. important::
+
+            **returns**: experiment version details.\n
+            **return type**: dict\n
+
+        **Example**
 
             >>> stored_experiment_revision_details = client.repository.create_experiment_revision(experiment_uid)
-
-         """
+        """
 
         return self._client.experiments.create_revision(experiment_id=experiment_uid)
 
     def update_model(self, model_uid, updated_meta_props=None, update_model=None):
         """
-                Updates existing model metadata.
+        Updates existing model metadata.
 
-                **Parameters**
+        **Parameters**
 
-                .. important::
+        .. important::
 
-                    #. **model_uid**:  Unique id of model which definition should be updated\n
-                       **type**: str\n
+            #. **model_uid**: Unique id of model which definition should be updated\n
+               **type**: str\n
 
-                    #. **updated_meta_props**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                       **type**: dict\n
+            #. **updated_meta_props**: elements which should be changed, where keys are ConfigurationMetaNames\n
+               **type**: dict\n
 
-                     #. **update_model**:  archived model content file or path to directory containing archived model file which should be changed for specific model_uid\n.
-                                  This parameters is valid only for CP4D 3.0.0.
-                                  A way you might use me with local directory containing model file(s):
-                        **type**: object or  archived model content file\n
+            #. **update_model**: archived model content file or path to directory containing archived model file which should be changed for specific model_uid.
+               This parameters is valid only for CP4D 3.0.0.\n
+               **type**: object or archived model content file\n
 
-                **Output**
+        **Output**
 
-                .. important::
+        .. important::
 
-                      **returns**: metadata of updated model\n
-                      **return type**: dict\n
+            **returns**: metadata of updated model\n
+            **return type**: dict\n
 
-                **Example 1**
-
-                 >>> metadata = {
-                 >>> client.repository.ModelMetaNames.NAME:"updated_model"
-                 >>> }
-                 >>> model_details = client.repository.update_model(model_uid, updated_meta_props=metadata)
-
-               **Example 2**
-
-                 >>> metadata = {
-                 >>> client.repository.ModelMetaNames.NAME:"updated_model"
-                 >>> }
-                 >>> model_details = client.repository.update_model(model_uid, updated_meta_props=metadata, update_model="newmodel_content.tar.gz")
+        **Example 1**
 
+         >>> metadata = {
+         >>> client.repository.ModelMetaNames.NAME:"updated_model"
+         >>> }
+         >>> model_details = client.repository.update_model(model_uid, updated_meta_props=metadata)
 
+        **Example 2**
 
+         >>> metadata = {
+         >>> client.repository.ModelMetaNames.NAME:"updated_model"
+         >>> }
+         >>> model_details = client.repository.update_model(model_uid, updated_meta_props=metadata, update_model="newmodel_content.tar.gz")
         """
 
         return self._client._models.update(model_uid, updated_meta_props, update_model)
@@ -710,34 +738,36 @@ class Repository(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def update_function(self, function_uid, changes, update_function=None):
         """
-                Updates existing function metadata.
+        Updates existing function metadata.
 
-                **Parameters**
+        **Parameters**
 
-                .. important::
+        .. important::
 
-                       #. **function_uid**: Unique Id of function which define what should be updated\n
-                          **type**: str\n
-                       #. **changes**:  elements which should be changed, where keys are ConfigurationMetaNames\n
-                          **type**: dict\n
-                       #. **update_function**:  path to file with archived function content or function which should be changed for specific function_uid\n.This parameters is valid only for CP4D 3.0.0.
-                          **type**: str or function\n
+            #. **function_uid**: Unique Id of function which define what should be updated\n
+               **type**: str\n
 
-                **Output**
+            #. **changes**: Elements which should be changed, where keys are ConfigurationMetaNames.\n
+               **type**: dict\n
 
-                .. important::
+            #. **update_function**:  Path to file with archived function content or function which should be changed for specific function_uid.
+               This parameters is valid only for CP4D 3.0.0.\n
+               **type**: str or function\n
 
-                       **returns**: metadata of updated function\n
-                       **return type**: dict\n
+        **Output**
 
-                **Example**
+        .. important::
 
-                     >>> metadata = {
-                     >>> client.repository.FunctionMetaNames.NAME:"updated_function"
-                     >>> }
-                     >>>
-                     >>> function_details = client.repository.update_function(function_uid, changes=metadata)
+            **returns**: metadata of updated function\n
+            **return type**: dict\n
 
+        **Example**
+
+            >>> metadata = {
+            >>> client.repository.FunctionMetaNames.NAME:"updated_function"
+            >>> }
+            >>>
+            >>> function_details = client.repository.update_function(function_uid, changes=metadata)
         """
         return self._client._functions.update(function_uid, changes, update_function)
 
@@ -1073,8 +1103,7 @@ class Repository(WMLResource):
 
            .. important::
                 **returns**: metadata of model(s)\n
-                **return type**: dict
-                dict (if model_uid is not None) or {"resources": [dict]} (if model_uid is None)\n
+                **return type**: dict (if model_uid is not None) or {"resources": [dict]} (if model_uid is None)\n
 
            .. note::
                 If model_uid is not specified, all models metadata is fetched\n
@@ -1107,6 +1136,7 @@ class Repository(WMLResource):
                 **return type**: dict\n
 
            **Example**
+
                  >>> model_rev_details = client.respository.get_model_revision_details(model_uid, rev_uid)
 
         """
@@ -1175,6 +1205,7 @@ class Repository(WMLResource):
                 **return type**: dict\n
 
            **Example**
+
                  >>> experiment_rev_details = client.respository.get_experiment__revision_details(experiment_uid, rev_uid)
 
         """
@@ -1204,8 +1235,7 @@ class Repository(WMLResource):
 
            .. important::
                 **returns**: function(s) metadata\n
-                **return type**: dict\n
-                dict (if function_uid is not None) or {"resources": [dict]} (if function_uid is None)\n
+                **return type**: dict (if function_uid is not None) or {"resources": [dict]} (if function_uid is None)\n
 
            .. note::
                 If function_uid is not specified, all functions metadata is fetched\n
@@ -1214,7 +1244,6 @@ class Repository(WMLResource):
 
                 >>> function_details = client.respository.get_function_details(function_uid)
                 >>> function_details = client.respository.get_function_details()
-
          """
         Repository._validate_type(function_uid, u'function_uid', STR_TYPE, False)
         Repository._validate_type(limit, u'limit', int, False)
@@ -1267,8 +1296,7 @@ class Repository(WMLResource):
 
            .. important::
                 **returns**: metadata of pipeline(s)\n
-                **return type**: dict
-                dict (if pipeline_uid is not None) or {"resources": [dict]} (if pipeline_uid is None)\n
+                **return type**: dict (if pipeline_uid is not None) or {"resources": [dict]} (if pipeline_uid is None)\n
 
            .. note::
                 If pipeline_uid is not specified, all pipelines metadata is fetched\n
@@ -1330,8 +1358,7 @@ class Repository(WMLResource):
 
            .. important::
                 **returns**: metadata of space(s)\n
-                **return type**: dict
-                dict (if space_uid is not None) or {"resources": [dict]} (if space_uid is None)\n
+                **return type**: dict (if space_uid is not None) or {"resources": [dict]} (if space_uid is None)\n
 
            .. note::
                 If space_uid is not specified, all spaces metadata is fetched\n
@@ -1365,8 +1392,7 @@ class Repository(WMLResource):
 
            .. important::
                 **returns**: metadata of member(s) of a space\n
-                **return type**: dict
-                dict (if member_id is not None) or {"resources": [dict]} (if member_id is None)\n
+                **return type**: dict (if member_id is not None) or {"resources": [dict]} (if member_id is None)\n
 
            .. note::
                 If member id is not specified, all members metadata is fetched\n
@@ -1478,6 +1504,7 @@ class Repository(WMLResource):
                 **return type**: str\n
 
            **Example**
+
             >>> experiment_details = client.repository.get_experiment_detailsf(experiment_uid)
             >>> experiment_uid = client.repository.get_experiment_uid(experiment_details)
 
@@ -1506,6 +1533,7 @@ class Repository(WMLResource):
                 **return type**: str\n
 
            **Example**
+
             >>> experiment_details = client.repository.get_experiment_details(experiment_uid)
             >>> experiment_uid = client.repository.get_experiment_id(experiment_details)
 
@@ -1534,6 +1562,7 @@ class Repository(WMLResource):
                 **return type**: str\n
 
            **Example**
+
              >>> experiment_details = client.repository.get_experiment_detailsf(experiment_uid)
              >>> experiment_href = client.repository.get_experiment_href(experiment_details)
 
@@ -2154,18 +2183,25 @@ class Repository(WMLResource):
     @docstring_parameter({'str_type': STR_TYPE_NAME})
     def create_revision(self, artifact_uid):
         """
-                   Create revision for passed artifact_uid.
+        Create revision for passed artifact_uid.
 
-                   :param artifact_uid:  unique id of stored model, experiment, function or pipelines 
-                   :type artifact_uid: {str_type}
+        **Parameters**
 
-                   :returns:  artifact new revision metadata
-                   :rtype: dict
+        .. important::
 
-                   A way you might use me is:
+            #. **artifact_uid**: Unique id of stored model, experiment, function or pipelines.\n
+               **type**: str\n
 
-                   >>> details = client.repository.create_revision(artifact_uid)
+        **Output**
 
+        .. important::
+
+            **returns**: Artifact new revision metadata.\n
+            **return type**: dict\n
+
+        **Example**
+
+            >>> details = client.repository.create_revision(artifact_uid)
         """
         artifact_uid = str_type_conv(artifact_uid)
         Repository._validate_type(artifact_uid, u'artifact_uid', STR_TYPE, True)
@@ -2220,7 +2256,7 @@ class Repository(WMLResource):
            .. important::
                 #. **model_uid**:  Uniquie Id of the model \n
                    **type**: str\n
-           .. important::
+
                 #. **limit**:  limit number of fetched records\n
                    **type**: int\n
 
