@@ -4,6 +4,7 @@ from pprint import pprint
 import pandas as pd
 import traceback
 from os import environ
+import time
 
 from ibm_watson_machine_learning import APIClient
 
@@ -19,7 +20,9 @@ from ibm_watson_machine_learning.utils.autoai.errors import CannotReadSavedRemot
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, bucket_name_gen, get_space_id
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
 
-from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass
+from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, RunStateTypes
+from ibm_watson_machine_learning.utils.autoai.utils import chose_model_output
+
 
 
 from lale import wrap_imported_operators
@@ -80,6 +83,10 @@ class TestAutoAIRemote(unittest.TestCase):
     OPTIMIZER_NAME = 'Bank xlsx wml_autoai binary test'
     DEPLOYMENT_NAME = "Bank AutoAI Deployment tests"
 
+    scoring_method = PositiveLabelClass.PRECISION_SCORE_MICRO
+    max_number_of_estimators = 2
+    best_pipeline_name_so_far = None
+
     project_id = None
     space_id = None
 
@@ -112,7 +119,7 @@ class TestAutoAIRemote(unittest.TestCase):
                                    cos_resource_instance_id=self.cos_resource_instance_id),
                       days_old=7)
         TestAutoAIRemote.space_id = get_space_id(self.wml_client, self.space_name,
-                                     cos_resource_instance_id=self.cos_resource_instance_id)
+                                                 cos_resource_instance_id=self.cos_resource_instance_id)
 
         if self.wml_client.ICP:
             self.wml_client.set.default_project(self.project_id)
@@ -165,7 +172,7 @@ class TestAutoAIRemote(unittest.TestCase):
                 location=AssetLocation(asset_id=asset_id))
             TestAutoAIRemote.results_connection = None
 
-        else: #for cloud and COS
+        else:  # for cloud and COS
             TestAutoAIRemote.data_connection = DataConnection(
                 connection=S3Connection(endpoint_url=self.cos_endpoint,
                                         access_key_id=self.cos_credentials['cos_hmac_keys']['access_key_id'],
@@ -209,9 +216,9 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column='y',
             positive_label='yes',
-            scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
+            scoring=self.scoring_method,
             test_size=0.1,
-            max_number_of_estimators=1,
+            max_number_of_estimators=self.max_number_of_estimators,
             excel_sheet=self.sheet_name,
             autoai_pod_version=self.pod_version
 
@@ -225,18 +232,49 @@ class TestAutoAIRemote(unittest.TestCase):
         print(parameters)
         self.assertIsInstance(parameters, dict, msg='Config parameters are not a dictionary instance.')
 
-    def test_05_fit_run_training_of_auto_ai_in_wml(self):
+    def test_05_fit_run_training_of_auto_ai_in_wml_asynch(self):
         TestAutoAIRemote.trained_pipeline_details = self.remote_auto_pipelines.fit(
             training_data_reference=[self.data_connection],
             training_results_reference=self.results_connection,
-            background_mode=False)
+            background_mode=True)
 
         TestAutoAIRemote.run_id = self.trained_pipeline_details['metadata']['id']
+        self.assertIsNotNone(self.run_id)
 
-        self.assertIsNotNone(self.data_connection.auto_pipeline_params,
-                             msg='DataConnection auto_pipeline_params was not updated.')
+    def test_06a_get_run_status(self):
+        status = self.remote_auto_pipelines.get_run_status()
+        self.assertNotEqual(status, RunStateTypes.COMPLETED)
 
-    def test_06_get_train_data(self):
+    def test_06b_get_run_details(self):
+        parameters = self.remote_auto_pipelines.get_run_details()
+        # print(parameters)
+        self.assertIsNotNone(parameters)
+
+    def test_07_get_summary(self):
+
+        print(f"Run status = {self.remote_auto_pipelines.get_run_status()}")
+        # note: check if first pipeline was generated
+
+        metrics = self.wml_client.training.get_details(self.run_id)['entity']['status'].get('metrics', [])
+        while chose_model_output("1") not in str(metrics) and self.remote_auto_pipelines.get_run_status() not in [
+            'failed', 'canceled']:
+            time.sleep(5)
+            print(".", end=" ")
+            metrics = self.wml_client.training.get_details(self.run_id)['entity']['status'].get('metrics', [])
+        # end note
+
+        print("\n 1st pipeline completed")
+        summary_df = self.remote_auto_pipelines.summary()
+        print(summary_df)
+
+        self.assertGreater(len(summary_df), 0,
+                           msg=f"Summary DataFrame is empty. While {len(metrics)} pipelines are in training_details['entity']['status']['metrics']")
+
+        # check if pipelines are not duplicated
+        self.assertEqual(len(summary_df.index.unique()), len(summary_df),
+                         msg="Some pipeline names are duplicated in the summary")
+
+    def test_08_get_train_data(self):
         TestAutoAIRemote.train_data = self.remote_auto_pipelines.get_data_connections()[0].read()
 
         print("train data sample:")
@@ -246,35 +284,91 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.X_values = self.train_data.drop(['y'], axis=1)[:10].values
         TestAutoAIRemote.y_values = self.train_data['y'][:10]
 
-    def test_07_get_run_status(self):
+    def test_09_get_best_pipeline_so_far(self):
+        best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
+        print(best_pipeline_params)
+        self.assertIn(f"holdout_{self.scoring_method}", str(best_pipeline_params))
+
+        summary_df = self.remote_auto_pipelines.summary()
+        print(summary_df)
+
+        TestAutoAIRemote.best_pipeline_name_so_far = summary_df.index[0]
+        print("\nGetting best calculated pipeline: ", self.best_pipeline_name_so_far)
+
+        pipeline = self.remote_auto_pipelines.get_pipeline()
+        print(f"Fetched pipeline type: {type(pipeline)}")
+
+    #################################
+    #      DEPLOYMENT SECTION       #
+    #################################
+
+    def test_10_deployment_setup_and_preparation(self):
+        TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
+                                              source_project_id=self.project_id,
+                                              source_space_id=self.space_id)
+
+        self.wml_client.set.default_space(self.space_id)
+        delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
+        self.wml_client.set.default_project(self.project_id) if self.project_id else None
+
+    def test_11__deploy__online_deploy_pipeline_from_autoai_on_wml(self):
+        self.service.create(
+            experiment_run_id=self.run_id,
+            model=self.best_pipeline_name_so_far,
+            deployment_name=self.DEPLOYMENT_NAME + self.best_pipeline_name_so_far)
+
+        self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
+        self.assertIsNotNone(self.service.name, msg="Online Deployment creation - name not set")
+        self.assertIsNotNone(self.service.scoring_url,
+                             msg="Online Deployment creation - mscoring url  missing")
+
+    def test_12_score_deployed_model(self):
+        nb_records = 5
+        predictions = self.service.score(payload=self.train_data.drop(['y'], axis=1)[:nb_records])
+        print(predictions)
+        self.assertIsNotNone(predictions)
+        self.assertEqual(len(predictions['predictions'][0]['values']), nb_records)
+
+    def test_13_list_deployments(self):
+        self.service.list()
+        params = self.service.get_params()
+        print(params)
+        self.assertIsNotNone(params)
+
+    ###########################################
+    #     TRAINING SECTION - FINISH RUN       #
+    ###########################################
+
+    def test_15_waiting_for_fitted_completed(self):
+        while self.remote_auto_pipelines.get_run_status() == 'running':
+            time.sleep(10)
+
         status = self.remote_auto_pipelines.get_run_status()
-        self.assertEqual(status, "completed", msg="AutoAI run didn't finished successfully. Status: {}".format(status))
 
-    def test_08_get_run_details(self):
-        parameters = self.remote_auto_pipelines.get_run_details()
-        # print(parameters)
-        self.assertIsNotNone(parameters)
+        self.assertEqual(status, RunStateTypes.COMPLETED,
+                         msg="AutoAI run didn't finished successfully. Status: {}".format(status))
 
-    def test_09_predict_using_fitted_pipeline(self):
+    def test_16_predict_using_fitted_pipeline(self):
         predictions = self.remote_auto_pipelines.predict(X=self.X_values[:5])
         print(predictions)
         self.assertGreater(len(predictions), 0)
 
-    def test_10_summary_listing_all_pipelines_from_wml(self):
+    def test_17_summary_listing_all_pipelines_from_wml(self):
         pipelines_details = self.remote_auto_pipelines.summary()
         print(pipelines_details)
+        self.assertGreaterEqual(len(pipelines_details), 4*self.max_number_of_estimators)
 
-    def test_11__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
+    def test_18__get_data_connections__return_a_list_with_data_connections_with_optimizer_params(self):
         data_connections = self.remote_auto_pipelines.get_data_connections()
         self.assertIsInstance(data_connections, list, msg="There should be a list container returned")
         self.assertIsInstance(data_connections[0], DataConnection,
                               msg="There should be a DataConnection object returned")
 
-    def test_12_get_pipeline_params_specific_pipeline_parameters(self):
+    def test_19_get_pipeline_params_specific_pipeline_parameters(self):
         pipeline_params = self.remote_auto_pipelines.get_pipeline_details(pipeline_name='Pipeline_1')
         print(pipeline_params)
 
-    def test_13__get_pipeline_params__fetch_best_pipeline_parameters__parameters_fetched_as_dict(self):
+    def test_20__get_pipeline_params__fetch_best_pipeline_parameters__parameters_fetched_as_dict(self):
         best_pipeline_params = self.remote_auto_pipelines.get_pipeline_details()
         print(best_pipeline_params)
 
@@ -282,7 +376,7 @@ class TestAutoAIRemote(unittest.TestCase):
     # LALE #
     ########
 
-    def test_14__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
+    def test_21__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
         TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
@@ -292,7 +386,7 @@ class TestAutoAIRemote(unittest.TestCase):
             X=self.X_values[:5])  # works with autoai_libs from branch `development` (date: 9th March 20)
         print(predictions)
 
-    def test_15_get_all_pipelines_as_lale(self):
+    def test_22_get_all_pipelines_as_lale(self):
         summary = self.remote_auto_pipelines.summary()
         print(summary)
         failed_pipelines = []
@@ -317,6 +411,17 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertEqual(len(failed_pipelines), 0, msg=f"Some pipelines failed. Full list: {failed_pipelines}")
 
+    ###########################################
+    #      DEPLOYMENT SECTION - DELETE        #
+    ###########################################
+    def test_25_delete_deployment(self):
+        print("Delete current deployment: {}".format(self.service.deployment_id))
+        self.service.delete()
+        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
+        self.wml_client.repository.delete(self.service.asset_id)
+        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
+
+
     # @unittest.skip("Skipped lale pretty print")
     # def test_16__pretty_print_lale__checks_if_generated_python_pipeline_code_is_correct(self):
     #     pipeline_code = self.lale_pipeline.pretty_print()
@@ -371,50 +476,6 @@ class TestAutoAIRemote(unittest.TestCase):
     #     predictions = self.pipeline.predict(self.X_values)
     #     print(predictions)
 
-    #################################
-    #      DEPLOYMENT SECTION       #
-    #################################
-
-    def test_21_deployment_setup_and_preparation(self):
-        TestAutoAIRemote.service = WebService(source_wml_credentials=self.wml_credentials.copy(),
-                                              source_project_id=self.project_id,
-                                              source_space_id=self.space_id)
-        self.wml_client.set.default_space(self.space_id)
-
-        delete_model_deployment(self.wml_client, deployment_name=self.DEPLOYMENT_NAME)
-
-        self.wml_client.set.default_project(self.project_id) if self.project_id else None
-
-    def test_22__deploy__online_deploy_best_computed_pipeline_from_autoai_on_wml(self):
-        self.service.create(
-            experiment_run_id=self.remote_auto_pipelines._engine._current_run_id,
-            model="Pipeline_3",
-            deployment_name=self.DEPLOYMENT_NAME)
-
-        self.assertIsNotNone(self.service.id, msg="Online Deployment creation - missing id")
-        self.assertIsNotNone(self.service.name, msg="Online Deployment creation - name not set")
-        self.assertIsNotNone(self.service.scoring_url,
-                             msg="Online Deployment creation - mscoring url  missing")
-
-    def test_23_score_deployed_model(self):
-        nb_records = 5
-        predictions = self.service.score(payload=self.train_data.drop(['y'], axis=1)[:nb_records])
-        print(predictions)
-        self.assertIsNotNone(predictions)
-        self.assertEqual(len(predictions['predictions'][0]['values']), nb_records)
-
-    def test_24_list_deployments(self):
-        self.service.list()
-        params = self.service.get_params()
-        print(params)
-        self.assertIsNotNone(params)
-
-    def test_25_delete_deployment(self):
-        print("Delete current deployment: {}".format(self.service.deployment_id))
-        self.service.delete()
-        self.wml_client.set.default_space(self.space_id) if not self.wml_client.default_space_id else None
-        self.wml_client.repository.delete(self.service.asset_id)
-        self.wml_client.set.default_project(self.project_id) if is_cp4d() else None
 
 if __name__ == '__main__':
     unittest.main()
