@@ -66,7 +66,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     space_name = 'tests_sdk_space'
 
-    asset_id = '3c1a2156-e816-4f4a-8ea3-4e823f16eb2d'
+    asset_id = None
 
     @classmethod
     def setUpClass(cls) -> None:
@@ -77,7 +77,7 @@ class TestAutoAIRemote(unittest.TestCase):
         cls.wml_credentials = get_wml_credentials()
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
-        #cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
+        cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
 
     def test_00a_space_cleanup(self):
         space_cleanup(self.wml_client,
@@ -94,6 +94,10 @@ class TestAutoAIRemote(unittest.TestCase):
         self.assertIsInstance(self.experiment, AutoAI, msg="Experiment is not of type AutoAI.")
 
     def test_02_save_remote_data_and_DataConNection_setup(self):
+        asset_details = self.wml_client.data_assets._create_asset('NFS asset',
+                                                                              file_path=self.data_location,
+                                                                              connection_id=self.connection_id)
+        TestAutoAIRemote.asset_id = self.wml_client.data_assets.get_id(asset_details)
         TestAutoAIRemote.data_connection = DataConnection(location=AssetLocation(asset_id=self.asset_id))
         TestAutoAIRemote.results_connection = None
 
