@@ -595,6 +595,8 @@ class TestOBMAndKB(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                self.assertWarnsRegex(Warning, "OBM",
+                                      msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(X=self.holdout_data.drop(['next_purchase'], axis=1).values[:1])
                 print(predictions)
@@ -648,6 +650,8 @@ class TestOBMAndKB(unittest.TestCase):
     def test_20c_get_pipeline_from_hyperopt(self):
         print("Get locally optimized pipeline...")
         new_pipeline_model = TestOBMAndKB.hyperopt_pipelines.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Hyperopt_pipeline_model is type: {type(new_pipeline_model)}")
         TestOBMAndKB.new_sklearn_pipeline = new_pipeline_model.export_to_sklearn_pipeline()
         self.assertIsInstance(
@@ -669,6 +673,8 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4',
                                                                         astype=self.experiment.PipelineTypes.SKLEARN)
         print(f"Fetched pipeline type: {type(self.pipeline)}")
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
         self.assertIsInstance(self.pipeline, Pipeline,
                               msg="Fetched pipeline is not of sklearn.Pipeline instance.")
@@ -689,6 +695,8 @@ class TestOBMAndKB(unittest.TestCase):
                               msg="data_join_graph was incorrectly loaded")
 
         TestOBMAndKB.pipeline = self.historical_opt.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
     @print_test_separators
     def test_25_get_obm_training_data_from_historical_optimizer(self):
