@@ -557,6 +557,8 @@ class TestOBMAndKB(unittest.TestCase):
     def test_19__get_pipeline__load_lale_pipeline__pipeline_loaded(self):
         print("Download and load Pipeline_4 as lale...")
         TestOBMAndKB.lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
+        self.assertWarnsRegex(Warning, "OBM",
+                              msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
 
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline,
@@ -573,6 +575,8 @@ class TestOBMAndKB(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                self.assertWarnsRegex(Warning, "OBM",
+                                     msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(X=self.holdout_data.drop(['next_purchase'], axis=1).values[:1])
                 print(predictions)
@@ -626,6 +630,8 @@ class TestOBMAndKB(unittest.TestCase):
     def test_20c_get_pipeline_from_hyperopt(self):
         print("Get locally optimized pipeline...")
         new_pipeline_model = TestOBMAndKB.hyperopt_pipelines.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                             msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Hyperopt_pipeline_model is type: {type(new_pipeline_model)}")
         TestOBMAndKB.new_sklearn_pipeline = new_pipeline_model.export_to_sklearn_pipeline()
         self.assertIsInstance(
@@ -647,6 +653,8 @@ class TestOBMAndKB(unittest.TestCase):
         TestOBMAndKB.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4',
                                                                         astype=self.experiment.PipelineTypes.SKLEARN)
         print(f"Fetched pipeline type: {type(self.pipeline)}")
+        self.assertWarnsRegex(Warning, "OBM",
+                             msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
         self.assertIsInstance(self.pipeline, Pipeline,
                               msg="Fetched pipeline is not of sklearn.Pipeline instance.")
@@ -667,6 +675,8 @@ class TestOBMAndKB(unittest.TestCase):
                               msg="data_join_graph was incorrectly loaded")
 
         TestOBMAndKB.pipeline = self.historical_opt.get_pipeline()
+        self.assertWarnsRegex(Warning, "OBM",
+                             msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
 
     @print_test_separators
     def test_25_get_obm_training_data_from_historical_optimizer(self):
