@@ -19,6 +19,7 @@ __all__ = [
     "RegressionAlgorithms",
     "PredictionType",
     "Metrics",
+    "Transformers",
     "DataConnectionTypes",
     "RunStateTypes",
     "PipelineTypes",
@@ -113,6 +114,36 @@ class Metrics:
     R2_SCORE = "r2"
 
 
+class Transformers:
+    """
+        Supported types of congito transformers names in autoai.
+    """
+    SQRT = "sqrt"
+    LOG = "log"
+    ROUND = "round"
+    SQUARE = "square"
+    CBRT = "cbrt"
+    SIN = "sin"
+    COS = "cos"
+    TAN = "tan"
+
+    ABS = "abs"
+    SIGMOID = "sigmoid"
+    PRODUCT = "product"
+    MAX = "max"
+    DIFF = "diff"
+    SUM = "sum"
+    DIVIDE = "divide"
+    STDSCALER = "stdscaler"
+
+    MINMAXSCALER = "minmaxscaler"
+    PCA = "pca"
+    NXOR = "nxor"
+    CUBE = "cube"
+    FEATUREAGGLOMERATION = "featureagglomeration"
+    ISOFORESTANOMALY = "isoforestanomaly"
+
+
 class DataConnectionTypes:
     """
         Supported types of DataConnection.
@@ -121,6 +152,7 @@ class DataConnectionTypes:
     S3 = "s3"
     FS = 'fs'
     DS = 'data_asset'
+    CA = 'connection_asset'
 
 
 class RunStateTypes:
