@@ -49,7 +49,8 @@ __all__ = [
     'NotWSDEnvironment',
     'NotExistingCOSResource',
     'AdditionalParameterIsUnexpected',
-    'OBMForNFSIsNotSupported'
+    'OBMForNFSIsNotSupported',
+    'OBMMainNodeAlreadySet'
 ]
 
 from ibm_watson_machine_learning.utils import WMLClientError
@@ -248,3 +249,9 @@ class AdditionalParameterIsUnexpected(WMLClientError):
 class OBMForNFSIsNotSupported(WMLClientError):
     def __init__(self):
         WMLClientError.__init__(self, f"OBM for NFS is not supported.")
+
+
+class OBMMainNodeAlreadySet(WMLClientError):
+    def __init__(self, param):
+        WMLClientError.__init__(self, f"OBM Main node is already set to: {param}. If you want to set the new one,"
+                                      f"please reinitialize entire object.")
