@@ -15,6 +15,7 @@
 __all__ = [
     'fetch_pipelines',
     'load_file_from_file_system',
+    'load_file_from_file_system_nonautoai',
     'NextRunDetailsGenerator',
     'prepare_auto_ai_model_to_publish_normal_scenario',
     'prepare_auto_ai_model_to_publish_notebook_normal_scenario',
@@ -47,21 +48,20 @@ __all__ = [
 import io
 import json
 import os
-from zipfile import ZipFile
 from contextlib import redirect_stdout
+from functools import wraps
 from subprocess import check_call
 from sys import executable
 from tarfile import open as open_tar
-from time import sleep
 from typing import Dict, Union, Tuple, List, TYPE_CHECKING, Optional
 from warnings import warn
-from functools import wraps
+from zipfile import ZipFile
 
+import pkg_resources
 import requests
-from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
+from packaging import version
 
-from .enums import RunStateTypes
-from .errors import (MissingPipeline, AutoAIComputeError, DataFormatNotSupported, LibraryNotCompatible,
+from .errors import (MissingPipeline, DataFormatNotSupported, LibraryNotCompatible,
                      CannotInstallLibrary, CannotDownloadTrainingDetails, CannotDownloadWMLPipelineDetails,
                      VisualizationFailed, AdditionalParameterIsUnexpected)
 
@@ -91,10 +91,10 @@ def create_model_download_link(file_path: str):
 
 def fetch_pipelines(run_params: dict,
                     path: str,
+                    wml_client: 'APIClient',
                     pipeline_name: str = None,
                     load_pipelines: bool = False,
-                    store: bool = False,
-                    wml_client: 'APIClient' = None) -> Union[None, Dict[str, 'Pipeline']]:
+                    store: bool = False) -> Union[None, Dict[str, 'Pipeline']]:
     """
     Helper function to download and load computed AutoAI pipelines (sklearn pipelines).
 
@@ -115,24 +115,32 @@ def fetch_pipelines(run_params: dict,
     store: bool, optional
         Indicator to store pipelines in local filesystem
 
-    wml_client: APIClient, optional
-        Should be passed when we are operating on CP4D instance.
+    wml_client: APIClient, required
 
     Returns
     -------
     List of sklearn Pipelines or None if load_pipelines is set to False.
     """
 
-    def check_pipeline_nodes(pipeline: dict) -> None:
+    def check_pipeline_nodes(pipeline: dict, request_json: dict, wml_client) -> None:
         """
         Automate check all pipeline nodes to find xgboost or lightgbm dependency.
         """
-        # note: check dependencies for estimators
-        for node in pipeline['context']['intermediate_model'].get('pipeline_nodes', []):
-            if 'XGBClassifierEstimator' == node or 'XGBRegressorEstimator' == node:
-                check_dependencies_versions(lib_name='xgboost', error=True)
-            elif 'LGBMClassifierEstimator' == node or 'LGBMRegressorEstimator' == node:
-                check_dependencies_versions(lib_name='lightgbm', error=True)
+        xgboost_estimators = ['XGBClassifierEstimator', 'XGBRegressorEstimator']
+        lightgbm_estimators = ['LGBMClassifierEstimator', 'LGBMRegressorEstimator']
+
+        # note: check dependencies for estimators and other packages
+        estimator_name = pipeline['context']['intermediate_model'].get('pipeline_nodes', [None])[-1]
+        if estimator_name in xgboost_estimators:
+            check_dependencies_versions(request_json, wml_client, 'xgboost')
+
+        elif estimator_name in lightgbm_estimators:
+            check_dependencies_versions(request_json, wml_client, 'lightgbm')
+
+        else:
+            check_dependencies_versions(request_json, wml_client, None)
+
+        # TODO: When another package estimators will be available update above!
         # --- end note
 
     joblib = try_import_joblib()
@@ -141,7 +149,7 @@ def fetch_pipelines(run_params: dict,
     pipelines_names = []
     pipelines = {}
 
-    if wml_client is not None:
+    if wml_client.ICP:
         model_paths = []
 
         # note: iterate over all computed pipelines
@@ -158,15 +166,17 @@ def fetch_pipelines(run_params: dict,
                     f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}")
 
                 # note: check dependencies for estimators
-                check_pipeline_nodes(pipeline=pipeline)
+                request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
+                check_pipeline_nodes(pipeline, request_json, wml_client)
 
             # checking only chosen pipeline
             elif pipeline_name == f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}":
                 model_paths.append(model_path)
                 pipelines_names = [f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}"]
 
-                # note: check dependencies for estimators
-                check_pipeline_nodes(pipeline=pipeline)
+                # note: check dependencies for estimators and other packages
+                request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
+                check_pipeline_nodes(pipeline, request_json, wml_client)
 
                 break
             # --- end note
@@ -201,8 +211,10 @@ def fetch_pipelines(run_params: dict,
         keys = []
 
         for pipeline in run_params['entity']['status'].get('metrics', []):
+            model_number = pipeline['context']['intermediate_model']['name'].split('P')[-1]
+            model_phase = chose_model_output(model_number)
 
-            if pipeline['context']['phase'] == 'global_output':
+            if pipeline['context']['phase'] == model_phase:
                 model_path = f"{pipeline['context']['intermediate_model']['location']['model']}"
 
                 if pipeline_name is None:
@@ -213,8 +225,9 @@ def fetch_pipelines(run_params: dict,
                     pipelines_names.append(
                         f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}")
 
-                    # note: check dependencies for estimators
-                    check_pipeline_nodes(pipeline=pipeline)
+                    # note: check dependencies for estimators and other packages
+                    request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
+                    check_pipeline_nodes(pipeline, request_json, wml_client)
 
                 elif pipeline_name == f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}":
                     buckets = [run_params['entity']['results_reference']['location']['bucket']]
@@ -223,8 +236,9 @@ def fetch_pipelines(run_params: dict,
                     keys = [model_path]
                     pipelines_names = [f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}"]
 
-                    # note: check dependencies for estimators
-                    check_pipeline_nodes(pipeline=pipeline)
+                    # note: check dependencies for estimators and other packages
+                    request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
+                    check_pipeline_nodes(pipeline, request_json, wml_client)
 
                     break
 
@@ -288,12 +302,59 @@ def load_file_from_file_system(wml_client: 'APIClient',
     # --- end note
 
     buffer = io.BytesIO()
-
     response_with_model = requests.get(
         url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}auto_ml/{file_path}",
         headers=wml_client._get_headers(),
         stream=stream,
         verify=False)
+    if stream:
+        for data in response_with_model.iter_content():
+            buffer.write(data)
+    else:
+        buffer.write(response_with_model.content)
+
+    buffer.seek(0)
+
+    return buffer
+
+
+def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
+                               file_path: str,
+                               stream: bool = True) -> 'io.BytesIO':
+    """
+    Load file into memory from the file system.
+
+    Parameters
+    ----------
+    wml_client: APIClient, required
+        WML v4 client.
+
+    file_path: str, required
+        Path in the file system of the file.
+
+    stream: bool, optional
+        Indicator to stream data content.
+
+    Returns
+    -------
+        File content
+    """
+    # note: prepare the file path
+
+    if wml_client.default_project_id:
+        file_path = f"{file_path}?project_id={wml_client.default_project_id}"
+
+    else:
+        file_path = f"{file_path}?space_id={wml_client.default_space_id}"
+    # --- end note
+
+    buffer = io.BytesIO()
+
+    response_with_model = requests.get(
+        url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}{file_path}",
+        headers=wml_client._get_headers(),
+        stream=stream,
+        verify=False)
 
     if stream:
         for data in response_with_model.iter_content():
@@ -305,7 +366,6 @@ def load_file_from_file_system(wml_client: 'APIClient',
 
     return buffer
 
-
 class NextRunDetailsGenerator:
     """
     Generator class to produce next list of run details.
@@ -550,33 +610,7 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
     else: path name to the stored model in COS
     """
 
-    pipeline_info = run_params['entity']['status'].get('metrics')[-1]
-    schema_path = f"{pipeline_info['context']['intermediate_model']['schema_location']}"
-    model_number = pipeline_model.split('_')[-1]
-    request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{chose_model_output(model_number)}/resources/wml_model/request.json"
-
-    if wml_client.ICP:
-        request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
-        # note: only if there was 1 estimator during training
-        if 'content_location' not in request_str:
-            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
-            request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
-
-    else:
-        cos_client = init_cos_client(run_params['entity']['results_reference']['connection'])
-        bucket = run_params['entity']['results_reference']['location']['bucket']
-        cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
-        with open('request.json', 'r') as f:
-            request_str = f.read()
-
-        # note: only if there was 1 estimator during training
-        if 'content_location' not in request_str:
-            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
-            cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
-            with open('request.json', 'r') as f:
-                request_str = f.read()
-
-    request_json: Dict[str, dict] = json.loads(request_str)
+    request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client)
     # note: fill connection details
     request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
     # note: if training was on project_id, change it to space_id as we can deploy only on space
@@ -800,7 +834,7 @@ def try_import_lale():
     """
     Check if lale package is installed in local environment, if not, just download and install it.
     """
-    lale_version = '0.4.4'
+    lale_version = '0.4.12'
     try:
         import lale
         from packaging import version
@@ -974,64 +1008,59 @@ def try_load_dataset(
     return data
 
 
-def check_dependencies_versions(lib_name: str = None, error: bool = False, msg: str = '') -> None:
-    """Check xgboost and lightbm installed versions and inform the user about needed ones.
+def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: str) -> None:
+    """
+    Check packages installed versions and inform the user about needed ones.
 
     Parameters
     ----------
-    lib_name: str, optional
-        Library name to check
+    request_json: dict, required
+        Dictionary with request from training saved on user COS or CP4D fs.
 
-    error: bool, optional
-        If True, raise an error when some library is missing or is incompatible.
+    wml_client: APIClient, required
+        Internal WML client used for sw spec requests.
 
-    msg: str, optional
-        Error message.
+    estimator_pkg: str, required
+        Name of the estimator package to check with.
     """
+    sw_spec_name = request_json.get('hybrid_pipeline_software_specs', [{'name': None}])[-1]['name']
+    sw_spec_id = wml_client.software_specifications.get_id_by_name(sw_spec_name)
+    sw_spec = wml_client.software_specifications.get_details(sw_spec_id)
 
-    xgboost_version = '0.90'
-    lightgbm_version = '2.2.3'
+    packages = sw_spec['entity']['software_specification']['software_configuration']['included_packages']
+    packages_to_check = ['numpy', 'scikit-learn', 'autoai-libs', 'gensim', 'lale']
 
-    xgboost_message = f'To use AutoAI with xgboost estimators, you need to have xgboost {xgboost_version} installed.'
-    lightgbm_message = f'To use AutoAI with lightgbm estimators, you need to have lightgbm {lightgbm_version} installed.'
+    if estimator_pkg is not None:
+        packages_to_check.append(estimator_pkg)
+        packages_to_check.append(f'py-{estimator_pkg}')
 
-    def print_or_warn(library: str) -> None:
-        if library == 'xgboost':
-            message = xgboost_message
+    errored_packages = []
+
+    for package in packages:
+        if package['name'] in packages_to_check:
+            try:
+                installed_module_version = pkg_resources.get_distribution(package['name']).version
+
+                # workaround for autai-libs and numpy versions in SW spec
+                if package['name'] == 'autoai-libs' or package['name'] == 'numpy':
+                    if version.parse(installed_module_version) < version.parse(package['version']):
+                        errored_packages.append(package)
+
+                else:
+                    if installed_module_version != package['version']:
+                        errored_packages.append(package)
+
+            except pkg_resources.DistributionNotFound as e:
+                errored_packages.append(package)
 
         else:
-            message = lightgbm_message
+            pass
 
-        if error:
-            raise LibraryNotCompatible(reason=f'{msg} {message}')
-
-        if is_ipython():
-            print(f'Warning: {message}')
-
-        else:
-            warn(message=message)
-
-    # note: xgboost version check
-    try:
-        if lib_name == 'xgboost' or lib_name is None:
-            import xgboost
-            if xgboost.__version__ != xgboost_version:
-                print_or_warn(library='xgboost')
-
-    except (ImportError, AttributeError, ModuleNotFoundError):
-        print_or_warn(library='xgboost')
-    # --- end note
-
-    # note: lightgbm version check
-    try:
-        if lib_name == 'lightgbm' or lib_name is None:
-            import lightgbm
-            if lightgbm.__version__ != lightgbm_version:
-                print_or_warn(library='lightgbm')
-
-    except (ImportError, AttributeError, ModuleNotFoundError):
-        print_or_warn(library='lightgbm')
-    # --- end note
+    if errored_packages:
+        raise LibraryNotCompatible(reason=f"Please check if you have installed correct versions "
+                                          f"of the following packages: {errored_packages} "
+                                          f"These packages are required to load ML model successfully "
+                                          f"on your environment.")
 
 
 def prepare_cos_client(
@@ -1111,7 +1140,6 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
     -------
     pandas.DataFrame with pipelines summary
     """
-    from ibm_watson_machine_learning.utils.autoai.enums import MetricsToDirections, Directions
     from pandas import DataFrame
 
     columns = (['Pipeline Name', 'Number of enhancements', 'Estimator'] +
@@ -1120,7 +1148,10 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
     values = []
 
     for pipeline in details['entity']['status'].get('metrics', []):
-        if pipeline['context']['phase'] == 'global_output':
+        model_number = pipeline['context']['intermediate_model']['name'].split('P')[-1]
+        model_phase = chose_model_output(model_number)
+
+        if pipeline['context']['phase'] == model_phase:
             number_of_enhancements = len(pipeline['context']['intermediate_model']['composition_steps']) - 5
 
             # note: workaround when some pipelines have less or more metrics computed
@@ -1144,25 +1175,22 @@ def create_summary(details: dict, scoring: str) -> 'DataFrame':
     pipelines.set_index('Pipeline Name', inplace=True)
 
     try:
-        if (MetricsToDirections[scoring.upper()].value ==
-                Directions.ASCENDING):
-            return pipelines.sort_values(
-                by=[f"training_{scoring}"], ascending=False).rename(
-                {
-                    f"training_{scoring}":
-                        f"training_{scoring}_(optimized)"
-                }, axis='columns')
-
-        else:
-            return pipelines.sort_values(by=[f"training_{scoring}"]).rename(
-                {
-                    f"training_{scoring}":
-                        f"training_{scoring}_(optimized)"
-                }, axis='columns')
+        pipelines = pipelines.sort_values(
+            by=[f"training_{scoring}"], ascending=False).rename(
+            {
+                f"training_{scoring}":
+                    f"training_{scoring}_(optimized)"
+            }, axis='columns')
 
     # note: sometimes backend will not return 'training_' prefix to the metric
     except KeyError:
-        return pipelines
+        pass
+
+    neg_columns = [col for col in pipelines if '_neg_' in col]
+    pipelines[neg_columns] = -pipelines[neg_columns]
+    pipelines = pipelines.rename(columns={col: col.replace('_neg_', '_') for col in neg_columns})
+
+    return pipelines
 
 
 def get_node_and_runtime_index(node_name: str, optimizer_config: dict) -> Tuple[int, int]:
@@ -1318,9 +1346,43 @@ def validate_additional_params_for_optimizer(params):
         'FE_drop_constant_columns_flag', 'FE_add_frequency_columns_flag', 'FE_add_missing_indicator_columns_flag',
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
-        'enabled_feature_engineering_as_json']
+        'enabled_feature_engineering_as_json', 'fairness_info']
 
     for k in params:
         if k not in expected_params:
             raise AdditionalParameterIsUnexpected(k)
 
+
+def download_request_json(run_params: dict, model_name: str, wml_client) -> dict:
+    run_id = run_params['metadata']['id']
+    pipeline_info = run_params['entity']['status'].get('metrics')[-1]
+    schema_path = f"{pipeline_info['context']['intermediate_model']['schema_location']}"
+    model_number = model_name.split('_')[-1]
+    request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_{chose_model_output(model_number)}/resources/wml_model/request.json"
+
+    if wml_client.ICP:
+        request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
+        # note: only if there was 1 estimator during training
+        if 'content_location' not in request_str:
+            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+            request_str = load_file_from_file_system(wml_client=wml_client, file_path=request_path).read().decode()
+
+    else:
+        cos_client = init_cos_client(run_params['entity']['results_reference']['connection'])
+        bucket = run_params['entity']['results_reference']['location']['bucket']
+        cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
+        with open('request.json', 'r') as f:
+            request_str = f.read()
+
+        # note: only if there was 1 estimator during training
+        if 'content_location' not in request_str:
+            request_path = f"{schema_path.split('/data/')[0]}/assets/{run_id}_P{model_number}_compose_model_type_output/resources/wml_model/request.json"
+            cos_client.meta.client.download_file(Bucket=bucket, Filename='request.json', Key=request_path)
+            with open('request.json', 'r') as f:
+                request_str = f.read()
+
+    request_json: Dict[str, dict] = json.loads(request_str)
+
+    return request_json
+
+
